JBoss Rich Faces SVN: r17388 - in root/cdk/trunk/plugins: generator/src/main/java/org/richfaces/cdk/model and 3 other directories.
by richfaces-svn-commits@lists.jboss.org
Author: alexsmirnov
Date: 2010-05-28 17:35:24 -0400 (Fri, 28 May 2010)
New Revision: 17388
Modified:
root/cdk/trunk/plugins/generator/src/main/java/org/richfaces/cdk/apt/processors/EventProcessor.java
root/cdk/trunk/plugins/generator/src/main/java/org/richfaces/cdk/model/EventModel.java
root/cdk/trunk/plugins/generator/src/main/java/org/richfaces/cdk/model/validator/ValidatorImpl.java
root/cdk/trunk/plugins/generator/src/main/resources/META-INF/templates/listenerTagHandler.ftl
root/cdk/trunk/plugins/maven-cdk-plugin/src/it/annotated-component/src/main/java/org/richfaces/cdk/test/event/TestEvent.java
Log:
RESOLVED - issue RF-7789: Process JSF events.
https://jira.jboss.org/browse/RF-7789
Modified: root/cdk/trunk/plugins/generator/src/main/java/org/richfaces/cdk/apt/processors/EventProcessor.java
===================================================================
--- root/cdk/trunk/plugins/generator/src/main/java/org/richfaces/cdk/apt/processors/EventProcessor.java 2010-05-28 19:43:18 UTC (rev 17387)
+++ root/cdk/trunk/plugins/generator/src/main/java/org/richfaces/cdk/apt/processors/EventProcessor.java 2010-05-28 21:35:24 UTC (rev 17388)
@@ -37,6 +37,7 @@
import org.richfaces.cdk.model.ClassName;
import org.richfaces.cdk.model.ComponentLibrary;
import org.richfaces.cdk.model.EventModel;
+import org.richfaces.cdk.util.Strings;
/**
* <p class="changed_added_4_0">This class processes annotations for FacesEvents.</p>
@@ -68,7 +69,10 @@
} catch (MirroredTypeException mirror) {
model.setListenerInterface(ClassName.parseName(mirror.getTypeMirror().toString()));
}
- model.setListenerMethodName(event.listenerMethod());
+ String listenerMethod = event.listenerMethod();
+ if(!Strings.isEmpty(listenerMethod)){
+ model.setListenerMethod(listenerMethod);
+ }
model.setSourceInterface(ClassName.parseName(event.source()));
for (Tag tag : event.tag()) {
if(!TagType.None.equals(tag.type())){
Modified: root/cdk/trunk/plugins/generator/src/main/java/org/richfaces/cdk/model/EventModel.java
===================================================================
--- root/cdk/trunk/plugins/generator/src/main/java/org/richfaces/cdk/model/validator/ValidatorImpl.java 2010-05-28 19:43:18 UTC (rev 17387)
+++ root/cdk/trunk/plugins/generator/src/main/java/org/richfaces/cdk/model/validator/ValidatorImpl.java 2010-05-28 21:35:24 UTC (rev 17388)
@@ -122,9 +122,11 @@
// TODO - infer listener interface name.
}
event.setGenerateListener(null == sourceUtils.asTypeElement(listenerInterface));
- String methodName = event.getListenerMethodName();
+ String methodName = event.getListenerMethod();
if (null == methodName) {
// TODO infer listener method name.
+ methodName="process";
+ event.setListenerMethod(methodName);
}
ClassName sourceInterface = event.getSourceInterface();
if (null == sourceInterface) {
Modified: root/cdk/trunk/plugins/generator/src/main/resources/META-INF/templates/listenerTagHandler.ftl
===================================================================
--- root/cdk/trunk/plugins/generator/src/main/resources/META-INF/templates/listenerTagHandler.ftl 2010-05-28 19:43:18 UTC (rev 17387)
+++ root/cdk/trunk/plugins/generator/src/main/resources/META-INF/templates/listenerTagHandler.ftl 2010-05-28 21:35:24 UTC (rev 17388)
@@ -0,0 +1,160 @@
+package ${tag.targetClass.package};
+
+import java.io.IOException;
+import java.io.Serializable;
+
+import javax.el.ELContext;
+import javax.el.MethodExpression;
+import javax.el.ValueExpression;
+import javax.faces.component.UIComponent;
+import javax.faces.context.FacesContext;
+import javax.faces.event.AbortProcessingException;
+import javax.faces.view.facelets.ComponentHandler;
+import javax.faces.view.facelets.FaceletContext;
+import javax.faces.view.facelets.TagAttribute;
+import javax.faces.view.facelets.TagAttributeException;
+import javax.faces.view.facelets.TagConfig;
+import javax.faces.view.facelets.TagException;
+import javax.faces.view.facelets.TagHandler;
+
+import ${model.type};
+import ${model.listenerInterface};
+import ${model.sourceInterface};
+
+public class ${tag.targetClass.simpleName} extends TagHandler {
+
+ @SuppressWarnings("serial")
+ public static final class LazyListener implements ${model.listenerInterface.simpleName}, Serializable {
+
+ private final String type;
+
+ private final ValueExpression binding;
+
+ public LazyListener(String type, ValueExpression binding) {
+ this.type = type;
+ this.binding = binding;
+ }
+
+ public void ${model.listenerMethod}(${model.type} event) throws AbortProcessingException {
+ ${model.listenerInterface.simpleName} instance = null;
+ FacesContext faces = FacesContext.getCurrentInstance();
+ if (faces == null) {
+ return;
+ }
+
+ if (this.binding != null) {
+ instance = (${model.listenerInterface.simpleName}) binding.getValue(faces.getELContext());
+ }
+
+ if (instance == null && this.type != null) {
+ try {
+ ClassLoader classLoader = Thread.currentThread().getContextClassLoader();
+ if (null == classLoader) {
+ classLoader = ${model.listenerInterface.simpleName}.class.getClassLoader();
+ }
+ instance = classLoader.loadClass(this.type).asSubclass(${model.listenerInterface.simpleName}.class).newInstance();
+ } catch (Exception e) {
+ throw new AbortProcessingException("Couldn't lazily instantiate ${model.listenerInterface.simpleName}", e);
+ }
+
+ if (this.binding != null) {
+ binding.setValue(faces.getELContext(), instance);
+ }
+ }
+
+ if (instance != null) {
+ instance.${model.listenerMethod}(event);
+ }
+ }
+ }
+
+ @SuppressWarnings("serial")
+ public static final class MethodExpressionListener implements ${model.listenerInterface.simpleName}, Serializable {
+
+ private MethodExpression methodExpression;
+
+ public MethodExpressionListener(MethodExpression methodExpression) {
+ super();
+ this.methodExpression = methodExpression;
+ }
+
+ public void ${model.listenerMethod}(${model.type} actionEvent) throws AbortProcessingException {
+ if (actionEvent == null) {
+ throw new NullPointerException();
+ }
+ FacesContext context = FacesContext.getCurrentInstance();
+ ELContext elContext = context.getELContext();
+ try {
+ methodExpression.invoke(elContext, new Object[] { actionEvent });
+ } catch (Exception e) {
+ new AbortProcessingException(e);
+ }
+ }
+ }
+
+ private TagAttribute binding;
+
+ private String listenerType;
+
+ private TagAttribute listenerMethod;
+
+ public TestListenerHandler(TagConfig config) {
+ super(config);
+
+ this.binding = this.getAttribute("binding");
+
+ TagAttribute type = this.getAttribute("type");
+ if (type != null) {
+ if (!type.isLiteral()) {
+ throw new TagAttributeException(type, "Must be a literal class name of type ${model.listenerInterface.simpleName}");
+ } else {
+ // test it out
+ }
+
+ this.listenerType = type.getValue();
+ } else {
+ this.listenerType = null;
+ }
+
+ this.listenerMethod = this.getAttribute("listener");
+
+ if (this.listenerMethod != null && this.binding != null) {
+ throw new TagException(this.tag, "Attributes 'listener' and 'binding' cannot be used simultaneously");
+ }
+
+ if (this.listenerMethod != null && this.listenerType != null) {
+ throw new TagException(this.tag, "Attributes 'listener' and 'type' cannot be used simultaneously");
+ }
+ }
+
+ /*
+ * (non-Javadoc)
+ *
+ * @see javax.faces.view.facelets.FaceletHandler#apply(javax.faces.view.facelets.FaceletContext,
+ * javax.faces.component.UIComponent)
+ */
+ public void apply(FaceletContext ctx, UIComponent parent) throws IOException {
+ if (null != parent && ComponentHandler.isNew(parent)) {
+ if (!(parent instanceof ${model.sourceInterface.simpleName})) {
+ throw new TagException(this.tag, "Parent is not of type ${model.sourceInterface.simpleName}, type is: " + parent);
+ }
+
+ ${model.sourceInterface.simpleName} as = (${model.sourceInterface.simpleName}) parent;
+
+ if (this.listenerMethod != null) {
+ MethodExpression listenerMethodExpression =
+ this.listenerMethod.getMethodExpression(ctx, Void.TYPE, new Class<?>[] { ${model.type}.class });
+
+ as.add${model.listenerInterface.simpleName}(new MethodExpressionListener(listenerMethodExpression));
+ } else {
+ ValueExpression b = null;
+ if (this.binding != null) {
+ b = this.binding.getValueExpression(ctx, ${model.listenerInterface.simpleName}.class);
+ }
+ ${model.listenerInterface.simpleName} listener = new LazyListener(this.listenerType, b);
+ as.add${model.listenerInterface.simpleName}(listener);
+ }
+ }
+ }
+
+}
Modified: root/cdk/trunk/plugins/maven-cdk-plugin/src/it/annotated-component/src/main/java/org/richfaces/cdk/test/event/TestEvent.java
===================================================================
--- root/cdk/trunk/plugins/maven-cdk-plugin/src/it/annotated-component/src/main/java/org/richfaces/cdk/test/event/TestEvent.java 2010-05-28 19:43:18 UTC (rev 17387)
+++ root/cdk/trunk/plugins/maven-cdk-plugin/src/it/annotated-component/src/main/java/org/richfaces/cdk/test/event/TestEvent.java 2010-05-28 21:35:24 UTC (rev 17388)
@@ -37,7 +37,10 @@
* @author asmirnov(a)exadel.com
*
*/
-@Event(listener = TestListener.class, source = "org.richfaces.cdk.test.event.TestSource", tag = @Tag(name = "testListener"))
+@Event(listener = TestListener.class,
+ source = "org.richfaces.cdk.test.event.TestSource",
+ listenerMethod="process",
+ tag = @Tag(name = "testListener", generate = true, handler = "org.richfaces.cdk.test.view.facelets.TestListenerHandler"))
public class TestEvent extends FacesEvent {
/**
@@ -74,7 +77,7 @@
@Override
public void processListener(FacesListener listener) {
if (listener instanceof TestListener) {
- TestListener testListener= (TestListener) listener;
+ TestListener testListener = (TestListener) listener;
testListener.process(this);
}
}
14 years, 7 months
JBoss Rich Faces SVN: r17387 - in root/ui/core/trunk/ui/src/main/java/org/richfaces: view/facelets/html and 1 other directory.
by richfaces-svn-commits@lists.jboss.org
Author: nbelaevski
Date: 2010-05-28 15:43:18 -0400 (Fri, 28 May 2010)
New Revision: 17387
Added:
root/ui/core/trunk/ui/src/main/java/org/richfaces/view/facelets/html/ParameterHandler.java
Removed:
root/ui/core/trunk/ui/src/main/java/org/richfaces/view/facelets/html/AbstractParameterHandler.java
Modified:
root/ui/core/trunk/ui/src/main/java/org/richfaces/component/AbstractParameter.java
Log:
a4j:param:
- code style improvements applied
- Abstract* class made abstract
- PSH support added
- TagHadler class renamed
Modified: root/ui/core/trunk/ui/src/main/java/org/richfaces/component/AbstractParameter.java
===================================================================
--- root/ui/core/trunk/ui/src/main/java/org/richfaces/component/AbstractParameter.java 2010-05-28 19:41:30 UTC (rev 17386)
+++ root/ui/core/trunk/ui/src/main/java/org/richfaces/component/AbstractParameter.java 2010-05-28 19:43:18 UTC (rev 17387)
@@ -21,16 +21,10 @@
package org.richfaces.component;
-import org.ajax4jsf.Messages;
-import org.ajax4jsf.component.JavaScriptParameter;
-import org.richfaces.cdk.annotations.JsfComponent;
-import org.richfaces.cdk.annotations.Tag;
-import org.richfaces.cdk.annotations.TagType;
-
import javax.el.ELContext;
import javax.el.ValueExpression;
import javax.faces.FacesException;
-import javax.faces.component.UIComponentBase;
+import javax.faces.component.PartialStateHolder;
import javax.faces.component.UIParameter;
import javax.faces.context.FacesContext;
import javax.faces.convert.Converter;
@@ -38,23 +32,26 @@
import javax.faces.event.ActionEvent;
import javax.faces.event.ActionListener;
+import org.ajax4jsf.Messages;
+import org.ajax4jsf.component.JavaScriptParameter;
+import org.richfaces.cdk.annotations.JsfComponent;
+import org.richfaces.cdk.annotations.Tag;
+import org.richfaces.cdk.annotations.TagType;
+import org.richfaces.util.PartialStateHolderUtil;
+
/**
* @author shura (latest modification by $Author: alexsmirnov $)
* @version $Revision: 1.1.2.2 $ $Date: 2007/02/01 15:31:55 $
*/
-@JsfComponent(tag = @Tag(name = "param", handler = "org.richfaces.view.facelets.html.AbstractParameterHandler", generate = false, type = TagType.Facelets))
-public class AbstractParameter extends UIParameter implements ActionListener,
- JavaScriptParameter {
- public static final String COMPONENT_TYPE = "org.richfaces.UIParameter";
- private static String noEscapeAttr = "noEscape";
+@JsfComponent(tag = @Tag(name = "param", handler = "org.richfaces.view.facelets.html.ParameterHandler", generate = false, type = TagType.Facelets))
+public abstract class AbstractParameter extends UIParameter implements ActionListener, JavaScriptParameter {
+
+ public static final String COMPONENT_TYPE = "org.richfaces.Parameter";
- /** ********************************************************* */
+ public static final String COMPONENT_FAMILY = UIParameter.COMPONENT_FAMILY;
+
+ private static final String ASSIGN_TO = "assignTo";
- /**
- * Binding for update on ActionEvent
- */
- private ValueExpression assignToBinding = null;
-
/** ********************************************************* */
/**
@@ -64,21 +61,20 @@
/** ********************************************************* */
- /**
- * Skip quota escaping of parameter value - for substitute JavaScript
- * exspression on submit
- */
- private Boolean noEscape = null;
-
- public void setAssignToBinding(ValueExpression propertyBinding) {
- this.assignToBinding = propertyBinding;
+ public abstract boolean isNoEscape();
+ public abstract void setNoEscape(boolean noEscape);
+
+ public void setAssignToExpression(ValueExpression ve) {
+ setValueExpression(ASSIGN_TO, ve);
}
- public ValueExpression getAssignToBinding() {
- return assignToBinding;
+ public ValueExpression getAssignToExpression() {
+ return getValueExpression(ASSIGN_TO);
}
public void setConverter(Converter converter) {
+ clearInitialState();
+
this.converter = converter;
}
@@ -86,54 +82,29 @@
return converter;
}
- /*
- * (non-Javadoc)
- *
- * @see org.ajax4jsf.framework.ajax.JavaScriptParameter#setNoEscape(boolean)
- */
-
- public void setNoEscape(boolean noEscape) {
- this.noEscape = Boolean.valueOf(noEscape);
- }
-
- /*
- * (non-Javadoc)
- *
- * @see org.ajax4jsf.framework.ajax.JavaScriptParameter#isNoEscape()
- */
-
- public boolean isNoEscape() {
- return isValueOrBinding(noEscape, noEscapeAttr);
- }
-
- /*
- * (non-Javadoc)
- *
- * @see javax.faces.event.ActionListener#processAction(javax.faces.event.ActionEvent)
- */
-
public void processAction(ActionEvent actionEvent)
throws AbortProcessingException {
FacesContext context = getFacesContext();
ELContext elContext = context.getELContext();
- ValueExpression updateBinding = getAssignToBinding();
+ ValueExpression updateBinding = getAssignToExpression();
if (updateBinding != null && (!updateBinding.isReadOnly(elContext))) {
- Object requestValue = context.getExternalContext()
+ String requestValue = context.getExternalContext()
.getRequestParameterMap().get(getName());
- if (requestValue != null && requestValue instanceof String) {
+ Object convertedValue = requestValue;
+
+ if (requestValue != null) {
Class<?> type = updateBinding.getType(elContext);
Converter converter = createConverter(context, type);
if (null != converter) {
- requestValue = converter.getAsObject(context, this,
- (String) requestValue);
+ convertedValue = converter.getAsObject(context, this, requestValue);
}
}
- if (null != requestValue) {
- updateBinding.setValue(elContext, requestValue);
+ if (null != convertedValue) {
+ updateBinding.setValue(elContext, convertedValue);
}
}
}
@@ -197,67 +168,62 @@
return converter;
}
- /*
- * (non-Javadoc)
- *
- * @see javax.faces.component.UIComponentBase#restoreState(javax.faces.context.FacesContext)
- */
-
@Override
- public void restoreState(FacesContext context, Object state) {
- Object[] values = (Object[]) state;
+ public void markInitialState() {
+ super.markInitialState();
+
+ Converter c = getConverter();
+ if (c instanceof PartialStateHolder) {
+ ((PartialStateHolder) c).markInitialState();
+ }
+ }
- super.restoreState(context, values[0]);
- // restore fields values
- assignToBinding = (ValueExpression) UIComponentBase
- .restoreAttachedState(context, values[1]);
- noEscape = (Boolean) values[2];
- converter = (Converter) UIComponentBase.restoreAttachedState(context,
- values[3]);
+ @Override
+ public void clearInitialState() {
+ if (initialStateMarked()) {
+ super.clearInitialState();
+
+ Converter c = getConverter();
+ if (c instanceof PartialStateHolder) {
+ ((PartialStateHolder) c).clearInitialState();
+ }
+ }
}
- /*
- * (non-Javadoc)
- *
- * @see javax.faces.component.UIComponentBase#saveState(javax.faces.context.FacesContext)
- */
@Override
public Object saveState(FacesContext context) {
- Object[] values = new Object[5];
-
- values[0] = super.saveState(context);
-
- // save fields values
- values[1] = UIComponentBase.saveAttachedState(context, assignToBinding);
- values[2] = noEscape;
- values[3] = UIComponentBase.saveAttachedState(context, converter);
-
- return values;
+ if (context == null) {
+ throw new NullPointerException();
+ }
+
+ Object superState = super.saveState(context);
+ Object converterState = PartialStateHolderUtil.saveState(context, this, converter);
+
+ if (superState == null && converterState == null) {
+ return null;
+ }
+
+ return new Object[] {
+ superState,
+ converterState
+ };
}
- /**
- * @param field -
- * value of field to get.
- * @param name -
- * name of field, to get from ValueBinding
- * @return boolean value, based on field or valuebinding.
- */
- private boolean isValueOrBinding(Boolean field, String name) {
- if (null != field) {
- return field.booleanValue();
+
+ @Override
+ public void restoreState(FacesContext context, Object state) {
+ if (context == null) {
+ throw new NullPointerException();
}
- ValueExpression vb = getValueExpression(name);
-
- if (null != vb) {
- FacesContext context = getFacesContext();
- ELContext elContext = context.getELContext();
-
- return ((Boolean) vb.getValue(elContext)).booleanValue();
- } else {
- return false;
+ if (state == null) {
+ return;
}
+
+ Object[] values = (Object[]) state;
+ super.restoreState(context, values[0]);
+ converter = (Converter) PartialStateHolderUtil.restoreState(context, values[1], converter);
}
}
Deleted: root/ui/core/trunk/ui/src/main/java/org/richfaces/view/facelets/html/AbstractParameterHandler.java
===================================================================
--- root/ui/core/trunk/ui/src/main/java/org/richfaces/view/facelets/html/AbstractParameterHandler.java 2010-05-28 19:41:30 UTC (rev 17386)
+++ root/ui/core/trunk/ui/src/main/java/org/richfaces/view/facelets/html/AbstractParameterHandler.java 2010-05-28 19:43:18 UTC (rev 17387)
@@ -1,173 +0,0 @@
-/**
- * License Agreement.
- *
- * Rich Faces - Natural Ajax for Java Server Faces (JSF)
- *
- * Copyright (C) 2007 Exadel, Inc.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License version 2.1 as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- */
-
-package org.richfaces.view.facelets.html;
-
-import org.ajax4jsf.Messages;
-import org.richfaces.component.AbstractParameter;
-
-import javax.faces.component.ActionSource;
-import javax.faces.component.UIComponent;
-import javax.faces.convert.Converter;
-import javax.faces.view.facelets.ComponentConfig;
-import javax.faces.view.facelets.ComponentHandler;
-import javax.faces.view.facelets.FaceletContext;
-import javax.faces.view.facelets.MetaRule;
-import javax.faces.view.facelets.MetaRuleset;
-import javax.faces.view.facelets.Metadata;
-import javax.faces.view.facelets.MetadataTarget;
-import javax.faces.view.facelets.TagAttribute;
-import javax.faces.view.facelets.TagAttributeException;
-
-/**
- * @author shura (latest modification by $Author: alexsmirnov $)
- * @version $Revision: 1.1.2.1 $ $Date: 2007/02/01 15:31:23 $
- */
-public class AbstractParameterHandler extends ComponentHandler {
-
- private static final ActionParamMetaRule ACTION_PARAM_META_RULE = new ActionParamMetaRule();
-
- /**
- * @author shura (latest modification by $Author: alexsmirnov $)
- * @version $Revision: 1.1.2.1 $ $Date: 2007/02/01 15:31:23 $
- */
- public static class ActionParamMetaRule extends MetaRule {
-
- /*
- * (non-Javadoc)
- *
- * @see org.ajax4jsf.tag.SuggestionHandler.SuggestionMetaRule#applyRule(java.lang.String,
- * com.sun.facelets.tag.TagAttribute,
- * com.sun.facelets.tag.MetadataTarget)
- */
-
- public Metadata applyRule(String name, TagAttribute attribute,
- MetadataTarget meta) {
- if (meta.isTargetInstanceOf(AbstractParameter.class)) {
- if ("assignTo".equals(name)) {
- return new AssignToValueBindingMetadata(attribute);
- } else if ("converter".equals(name)) {
- if (attribute.isLiteral()) {
- return new LiteralConverterMetadata(attribute
- .getValue());
- } else {
- return new DynamicConverterMetadata(attribute);
- }
-
- }
- }
-
- return null;
- }
-
- }
-
- static final class LiteralConverterMetadata extends Metadata {
-
- private final String converterId;
-
- public LiteralConverterMetadata(String converterId) {
- this.converterId = converterId;
- }
-
- public void applyMetadata(FaceletContext ctx, Object instance) {
- ((AbstractParameter) instance).setConverter(ctx.getFacesContext()
- .getApplication().createConverter(this.converterId));
- }
- }
-
- static final class DynamicConverterMetadata extends Metadata {
-
- private final TagAttribute attr;
-
- public DynamicConverterMetadata(TagAttribute attr) {
- this.attr = attr;
- }
-
- public void applyMetadata(FaceletContext ctx, Object instance) {
- ((AbstractParameter) instance).setConverter((Converter) this.attr
- .getObject(ctx, Converter.class));
- }
- }
-
- static final class AssignToValueBindingMetadata extends Metadata {
-
- private final TagAttribute attr;
-
- public AssignToValueBindingMetadata(TagAttribute attr) {
- this.attr = attr;
- }
-
- public void applyMetadata(FaceletContext ctx, Object instance) {
- ((AbstractParameter) instance).setAssignToBinding(attr
- .getValueExpression(ctx, Object.class));
- }
- }
-
- private TagAttribute assignTo;
- private TagAttribute converter;
-
- /**
- * @param config
- */
- public AbstractParameterHandler(ComponentConfig config) {
- super(config);
- assignTo = getAttribute("assignTo");
- converter = getAttribute("converter");
-
- if (null != assignTo) {
- if (assignTo.isLiteral()) {
- throw new TagAttributeException(this.tag, this.assignTo,
- Messages.getMessage(Messages.MUST_BE_EXPRESSION_ERROR));
- }
- }
- }
-
- /*
- * (non-Javadoc)
- *
- * @see com.sun.facelets.FaceletHandler#apply(com.sun.facelets.FaceletContext,
- * javax.faces.component.UIComponent)
- */
-
- public void onComponentCreated(FaceletContext ctx, UIComponent c,
- UIComponent parent) {
- if (parent instanceof ActionSource) {
- if (assignTo != null) {
- AbstractParameter al = (AbstractParameter) c;
- ((ActionSource) parent).addActionListener(al);
- }
- }
- }
-
- /*
- * (non-Javadoc)
- *
- * @see org.ajax4jsf.tag.AjaxComponentHandler#createMetaRuleset(java.lang.Class)
- */
-
- protected MetaRuleset createMetaRuleset(Class type) {
- MetaRuleset metaRules = super.createMetaRuleset(type);
- metaRules.addRule(ACTION_PARAM_META_RULE);
- return metaRules;
- }
-
-}
Copied: root/ui/core/trunk/ui/src/main/java/org/richfaces/view/facelets/html/ParameterHandler.java (from rev 17375, root/ui/core/trunk/ui/src/main/java/org/richfaces/view/facelets/html/AbstractParameterHandler.java)
===================================================================
--- root/ui/core/trunk/ui/src/main/java/org/richfaces/view/facelets/html/ParameterHandler.java (rev 0)
+++ root/ui/core/trunk/ui/src/main/java/org/richfaces/view/facelets/html/ParameterHandler.java 2010-05-28 19:43:18 UTC (rev 17387)
@@ -0,0 +1,171 @@
+/**
+ * License Agreement.
+ *
+ * Rich Faces - Natural Ajax for Java Server Faces (JSF)
+ *
+ * Copyright (C) 2007 Exadel, Inc.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License version 2.1 as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ */
+
+package org.richfaces.view.facelets.html;
+
+import javax.faces.component.ActionSource;
+import javax.faces.component.UIComponent;
+import javax.faces.convert.Converter;
+import javax.faces.view.facelets.ComponentConfig;
+import javax.faces.view.facelets.ComponentHandler;
+import javax.faces.view.facelets.FaceletContext;
+import javax.faces.view.facelets.MetaRule;
+import javax.faces.view.facelets.MetaRuleset;
+import javax.faces.view.facelets.Metadata;
+import javax.faces.view.facelets.MetadataTarget;
+import javax.faces.view.facelets.TagAttribute;
+import javax.faces.view.facelets.TagAttributeException;
+
+import org.ajax4jsf.Messages;
+import org.richfaces.component.AbstractParameter;
+
+/**
+ * @author shura (latest modification by $Author: alexsmirnov $)
+ * @version $Revision: 1.1.2.1 $ $Date: 2007/02/01 15:31:23 $
+ */
+public class ParameterHandler extends ComponentHandler {
+
+ private static final ActionParamMetaRule ACTION_PARAM_META_RULE = new ActionParamMetaRule();
+
+ /**
+ * @author shura (latest modification by $Author: alexsmirnov $)
+ * @version $Revision: 1.1.2.1 $ $Date: 2007/02/01 15:31:23 $
+ */
+ public static class ActionParamMetaRule extends MetaRule {
+
+ /*
+ * (non-Javadoc)
+ *
+ * @see org.ajax4jsf.tag.SuggestionHandler.SuggestionMetaRule#applyRule(java.lang.String,
+ * com.sun.facelets.tag.TagAttribute,
+ * com.sun.facelets.tag.MetadataTarget)
+ */
+
+ public Metadata applyRule(String name, TagAttribute attribute,
+ MetadataTarget meta) {
+ if (meta.isTargetInstanceOf(AbstractParameter.class)) {
+ if ("assignTo".equals(name)) {
+ return new AssignToValueExpressionMetadata(attribute);
+ } else if ("converter".equals(name)) {
+ if (attribute.isLiteral()) {
+ return new LiteralConverterMetadata(attribute
+ .getValue());
+ } else {
+ return new DynamicConverterMetadata(attribute);
+ }
+
+ }
+ }
+
+ return null;
+ }
+
+ }
+
+ static final class LiteralConverterMetadata extends Metadata {
+
+ private final String converterId;
+
+ public LiteralConverterMetadata(String converterId) {
+ this.converterId = converterId;
+ }
+
+ public void applyMetadata(FaceletContext ctx, Object instance) {
+ ((AbstractParameter) instance).setConverter(ctx.getFacesContext()
+ .getApplication().createConverter(this.converterId));
+ }
+ }
+
+ static final class DynamicConverterMetadata extends Metadata {
+
+ private final TagAttribute attr;
+
+ public DynamicConverterMetadata(TagAttribute attr) {
+ this.attr = attr;
+ }
+
+ public void applyMetadata(FaceletContext ctx, Object instance) {
+ ((AbstractParameter) instance).setConverter((Converter) this.attr
+ .getObject(ctx, Converter.class));
+ }
+ }
+
+ static final class AssignToValueExpressionMetadata extends Metadata {
+
+ private final TagAttribute attr;
+
+ public AssignToValueExpressionMetadata(TagAttribute attr) {
+ this.attr = attr;
+ }
+
+ public void applyMetadata(FaceletContext ctx, Object instance) {
+ ((AbstractParameter) instance).setAssignToExpression(attr
+ .getValueExpression(ctx, Object.class));
+ }
+ }
+
+ private TagAttribute assignTo;
+
+ /**
+ * @param config
+ */
+ public ParameterHandler(ComponentConfig config) {
+ super(config);
+ assignTo = getAttribute("assignTo");
+
+ if (null != assignTo) {
+ if (assignTo.isLiteral()) {
+ throw new TagAttributeException(this.tag, this.assignTo,
+ Messages.getMessage(Messages.MUST_BE_EXPRESSION_ERROR));
+ }
+ }
+ }
+
+ /*
+ * (non-Javadoc)
+ *
+ * @see com.sun.facelets.FaceletHandler#apply(com.sun.facelets.FaceletContext,
+ * javax.faces.component.UIComponent)
+ */
+
+ public void onComponentCreated(FaceletContext ctx, UIComponent c,
+ UIComponent parent) {
+ if (parent instanceof ActionSource) {
+ if (assignTo != null) {
+ AbstractParameter al = (AbstractParameter) c;
+ ((ActionSource) parent).addActionListener(al);
+ }
+ }
+ }
+
+ /*
+ * (non-Javadoc)
+ *
+ * @see org.ajax4jsf.tag.AjaxComponentHandler#createMetaRuleset(java.lang.Class)
+ */
+
+ protected MetaRuleset createMetaRuleset(Class type) {
+ MetaRuleset metaRules = super.createMetaRuleset(type);
+ metaRules.addRule(ACTION_PARAM_META_RULE);
+ return metaRules;
+ }
+
+}
14 years, 7 months
JBoss Rich Faces SVN: r17386 - root/core/trunk/impl/src/main/java/org/richfaces/util.
by richfaces-svn-commits@lists.jboss.org
Author: nbelaevski
Date: 2010-05-28 15:41:30 -0400 (Fri, 28 May 2010)
New Revision: 17386
Added:
root/core/trunk/impl/src/main/java/org/richfaces/util/PartialStateHolderUtil.java
Log:
PSH utility class initial check-in
Added: root/core/trunk/impl/src/main/java/org/richfaces/util/PartialStateHolderUtil.java
===================================================================
--- root/core/trunk/impl/src/main/java/org/richfaces/util/PartialStateHolderUtil.java (rev 0)
+++ root/core/trunk/impl/src/main/java/org/richfaces/util/PartialStateHolderUtil.java 2010-05-28 19:41:30 UTC (rev 17386)
@@ -0,0 +1,117 @@
+/*
+ * JBoss, Home of Professional Open Source
+ * Copyright 2010, Red Hat, Inc. and individual contributors
+ * by the @authors tag. See the copyright.txt in the distribution for a
+ * full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.richfaces.util;
+
+import java.io.Serializable;
+
+import javax.faces.component.PartialStateHolder;
+import javax.faces.component.StateHolder;
+import javax.faces.component.UIComponent;
+import javax.faces.component.UIComponentBase;
+import javax.faces.context.FacesContext;
+
+/**
+ * @author Nick Belaevski
+ *
+ */
+public final class PartialStateHolderUtil {
+
+ private static final class StateHolderObject implements Serializable {
+
+ private static final long serialVersionUID = 6157742187482213801L;
+
+ private boolean partialState;
+
+ private Object savedState;
+
+ public StateHolderObject(boolean partialState, Object savedState) {
+ super();
+ this.partialState = partialState;
+ this.savedState = savedState;
+ }
+
+ public boolean isPartialState() {
+ return partialState;
+ }
+
+ public Object getSavedState() {
+ return savedState;
+ }
+ }
+
+ private PartialStateHolderUtil() {
+ //utility class constructor
+ }
+
+ public static Object saveState(FacesContext context, UIComponent component, Object objectToSave) {
+ Object savedState = null;
+ boolean nullDelta = true;
+
+ boolean converterHasPartialState = false;
+
+ if (component.initialStateMarked()) {
+ if (objectToSave != null) {
+ if (objectToSave instanceof PartialStateHolder) {
+ // Delta
+ StateHolder holder = (StateHolder) objectToSave;
+ if (!holder.isTransient()) {
+ Object attachedState = holder.saveState(context);
+ if (attachedState != null) {
+ nullDelta = false;
+ savedState = attachedState;
+ }
+ converterHasPartialState = true;
+ } else {
+ savedState = null;
+ }
+ } else {
+ // Full
+ savedState = UIComponentBase.saveAttachedState(context, objectToSave);
+ nullDelta = false;
+ }
+ }
+
+ if (savedState == null && nullDelta) {
+ // No values
+ return null;
+ }
+ } else {
+ savedState = UIComponentBase.saveAttachedState(context, objectToSave);
+ }
+
+ return new StateHolderObject(converterHasPartialState, savedState);
+ }
+
+ public static Object restoreState(FacesContext context, Object savedState, Object existingObject) {
+ if (savedState != null) {
+ StateHolderObject stateHolderObject = (StateHolderObject) savedState;
+ if (stateHolderObject.isPartialState()) {
+ ((StateHolder) existingObject).restoreState(context, stateHolderObject.getSavedState());
+ return existingObject;
+ } else {
+ return UIComponentBase.restoreAttachedState(context, stateHolderObject.getSavedState());
+ }
+ } else {
+ return null;
+ }
+ }
+}
14 years, 7 months
JBoss Rich Faces SVN: r17385 - in root/examples/core-demo/trunk/src/main: webapp and 1 other directory.
by richfaces-svn-commits@lists.jboss.org
Author: amarkhel
Date: 2010-05-28 14:22:09 -0400 (Fri, 28 May 2010)
New Revision: 17385
Added:
root/examples/core-demo/trunk/src/main/webapp/param.xhtml
root/examples/core-demo/trunk/src/main/webapp/poll.xhtml
Modified:
root/examples/core-demo/trunk/src/main/java/org/richfaces/demo/CommandBean.java
root/examples/core-demo/trunk/src/main/webapp/welcome.xhtml
Log:
Sample for poll and param
Modified: root/examples/core-demo/trunk/src/main/java/org/richfaces/demo/CommandBean.java
===================================================================
--- root/examples/core-demo/trunk/src/main/java/org/richfaces/demo/CommandBean.java 2010-05-28 18:13:53 UTC (rev 17384)
+++ root/examples/core-demo/trunk/src/main/java/org/richfaces/demo/CommandBean.java 2010-05-28 18:22:09 UTC (rev 17385)
@@ -5,37 +5,56 @@
import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;
+import javax.faces.event.ActionEvent;
import javax.faces.event.AjaxBehaviorEvent;
@ManagedBean(name = "commandBean")
@SessionScoped
public class CommandBean implements Serializable {
- private static final long serialVersionUID = 3485896940723796437L;
-
- private String name;
+ private static final long serialVersionUID = 3485896940723796437L;
- public void setName(String name) {
- this.name = name;
- }
+ private String name;
- public String getName() {
- return name;
- }
+ private boolean pollEnabled;
- public void submit() {
- name = "Hello " + name;
- }
+ public boolean isPollEnabled() {
+ return pollEnabled;
+ }
- public void reset() {
- name = "";
- }
+ public void setPollEnabled(boolean pollEnabled) {
+ this.pollEnabled = pollEnabled;
+ }
- public Date getDate() {
- return new Date();
- }
+ public void setName(String name) {
+ this.name = name;
+ }
- public void listener(AjaxBehaviorEvent event) {
- System.out.println("CommandBean.listener()");
- }
+ public String getName() {
+ return name;
+ }
+
+ public void submit() {
+ name = "Hello " + name;
+ }
+
+ public void reset() {
+ name = "";
+ }
+
+ public Date getDate() {
+ return new Date();
+ }
+
+ public void listener(AjaxBehaviorEvent event) {
+ System.out.println("CommandBean.listener()");
+ }
+
+ public void enablePoll(ActionEvent event) {
+ setPollEnabled(true);
+ }
+
+ public void disablePoll(ActionEvent event) {
+ setPollEnabled(false);
+ }
}
Added: root/examples/core-demo/trunk/src/main/webapp/param.xhtml
===================================================================
--- root/examples/core-demo/trunk/src/main/webapp/param.xhtml (rev 0)
+++ root/examples/core-demo/trunk/src/main/webapp/param.xhtml 2010-05-28 18:22:09 UTC (rev 17385)
@@ -0,0 +1,28 @@
+<?xml version="1.0" encoding="UTF-8" ?>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml"
+ xmlns:f="http://java.sun.com/jsf/core"
+ xmlns:h="http://java.sun.com/jsf/html"
+ xmlns:ui="http://java.sun.com/jsf/facelets"
+ xmlns:a4j="http://richfaces.org/a4j">
+<f:view>
+ <h:head>
+ </h:head>
+ <h:body>
+ <h:form id="form">
+ <a4j:commandButton value="Set param value to Alex" render="param" >
+ <a4j:param name="username" value="Alex" assignTo="#{commandBean.name}" />
+ </a4j:commandButton>
+ <a4j:commandButton value="Get screen width" render="param2" >
+ <a4j:param name="username" value="screen.width" assignTo="#{commandBean.name}" noEscape="true" />
+ </a4j:commandButton>
+ </h:form>
+ <h:panelGroup id="param">
+ <h:outputText value="Name is: #{commandBean.name}"/>
+ </h:panelGroup>
+ <h:panelGroup id="param2">
+ <h:outputText value="Screen width is: #{commandBean.name}"/>
+ </h:panelGroup>
+ </h:body>
+</f:view>
+</html>
\ No newline at end of file
Added: root/examples/core-demo/trunk/src/main/webapp/poll.xhtml
===================================================================
--- root/examples/core-demo/trunk/src/main/webapp/poll.xhtml (rev 0)
+++ root/examples/core-demo/trunk/src/main/webapp/poll.xhtml 2010-05-28 18:22:09 UTC (rev 17385)
@@ -0,0 +1,26 @@
+<?xml version="1.0" encoding="UTF-8" ?>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml"
+ xmlns:f="http://java.sun.com/jsf/core"
+ xmlns:h="http://java.sun.com/jsf/html"
+ xmlns:ui="http://java.sun.com/jsf/facelets"
+ xmlns:a4j="http://richfaces.org/a4j">
+<f:view>
+ <h:head>
+ </h:head>
+ <h:body>
+ <h:form id="form">
+<h:panelGroup id="poll">
+ <a4j:poll enabled="#{commandBean.pollEnabled}" interval="5000" ontimer="return confirm('execute action?')">
+ <a4j:ajax event="timer" render="time" />
+ </a4j:poll>
+ </h:panelGroup>
+ <a4j:commandButton actionListener="#{commandBean.enablePoll}" value="Start polling" render="poll" />
+ <a4j:commandButton actionListener="#{commandBean.disablePoll}" value="Stop polling" render="poll" />
+ </h:form>
+ <h:panelGroup id="time">
+ <h:outputText value="#{commandBean.date}"/>
+ </h:panelGroup>
+ </h:body>
+</f:view>
+</html>
\ No newline at end of file
Modified: root/examples/core-demo/trunk/src/main/webapp/welcome.xhtml
===================================================================
--- root/examples/core-demo/trunk/src/main/webapp/welcome.xhtml 2010-05-28 18:13:53 UTC (rev 17384)
+++ root/examples/core-demo/trunk/src/main/webapp/welcome.xhtml 2010-05-28 18:22:09 UTC (rev 17385)
@@ -23,7 +23,9 @@
<li><h:link outcome="dynamicExecute">Server side execute/render</h:link></li>
<li><h:link outcome="queue">a4j:queue</h:link></li>
<li><h:link outcome="repeat">a4j:repeat</h:link></li>
- <li><h:link outcome="region">a4j:region</h:link></li>
+ <li><h:link outcome="region">a4j:region</h:link></li>
+ <li><h:link outcome="poll">a4j:poll</h:link></li>
+ <li><h:link outcome="param">a4j:param</h:link></li>
<li><h:link outcome="skinning">controls skinning</h:link></li>
</ul>
</center>
14 years, 7 months
JBoss Rich Faces SVN: r17384 - root/ui/iteration/trunk/tables/ui/src/main/resources/META-INF/resources.
by richfaces-svn-commits@lists.jboss.org
Author: konstantin.mishin
Date: 2010-05-28 14:13:53 -0400 (Fri, 28 May 2010)
New Revision: 17384
Modified:
root/ui/iteration/trunk/tables/ui/src/main/resources/META-INF/resources/extendedDataTable.js
Log:
correction of reordering algorithm
Modified: root/ui/iteration/trunk/tables/ui/src/main/resources/META-INF/resources/extendedDataTable.js
===================================================================
--- root/ui/iteration/trunk/tables/ui/src/main/resources/META-INF/resources/extendedDataTable.js 2010-05-28 18:10:52 UTC (rev 17383)
+++ root/ui/iteration/trunk/tables/ui/src/main/resources/META-INF/resources/extendedDataTable.js 2010-05-28 18:13:53 UTC (rev 17384)
@@ -217,12 +217,14 @@
};
var overReorder = function(event) {
- var thisElement = jQuery(this);
- var offset = thisElement.offset();
- jQuery(reorderMarkerElement).setPosition({top:offset.top + thisElement.height(), left:offset.left - 5});
- reorderMarkerElement.style.display = "block";
- thisElement.one("mouseout", outReorder);
- thisElement.one("mouseup", endReorder);
+ if (idOfReorderingColumn != this.className.match(new RegExp(WIDTH_CLASS_NAME_BASE + "([^\\W]*)"))[1]) {
+ var thisElement = jQuery(this);
+ var offset = thisElement.offset();
+ jQuery(reorderMarkerElement).setPosition({top:offset.top + thisElement.height(), left:offset.left - 5});
+ reorderMarkerElement.style.display = "block";
+ thisElement.one("mouseout", outReorder);
+ thisElement.one("mouseup", endReorder);
+ }
};
var outReorder = function(event) {
14 years, 7 months
JBoss Rich Faces SVN: r17383 - in root/ui: dist/trunk/richfaces-components-impl and 5 other directories.
by richfaces-svn-commits@lists.jboss.org
Author: jbalunas(a)redhat.com
Date: 2010-05-28 14:10:52 -0400 (Fri, 28 May 2010)
New Revision: 17383
Modified:
root/ui/dist/trunk/richfaces-components-api/pom.xml
root/ui/dist/trunk/richfaces-components-impl/pom.xml
root/ui/dist/trunk/richfaces-components-ui/pom.xml
root/ui/iteration/trunk/dist/richfaces-ui-iteration-api/pom.xml
root/ui/iteration/trunk/dist/richfaces-ui-iteration-impl/pom.xml
root/ui/iteration/trunk/dist/richfaces-ui-iteration-ui/pom.xml
root/ui/misc/trunk/dist/richfaces-ui-misc-ui/pom.xml
Log:
Updated references to faces-shade-transformers to release 1
Modified: root/ui/dist/trunk/richfaces-components-api/pom.xml
===================================================================
--- root/ui/dist/trunk/richfaces-components-api/pom.xml 2010-05-28 18:01:34 UTC (rev 17382)
+++ root/ui/dist/trunk/richfaces-components-api/pom.xml 2010-05-28 18:10:52 UTC (rev 17383)
@@ -37,7 +37,7 @@
<properties>
<assembly.projects.group>org.richfaces.ui</assembly.projects.group>
- <faces-shade-transformers.version>1-SNAPSHOT</faces-shade-transformers.version>
+ <faces-shade-transformers.version>1</faces-shade-transformers.version>
</properties>
<dependencyManagement>
Modified: root/ui/dist/trunk/richfaces-components-impl/pom.xml
===================================================================
--- root/ui/dist/trunk/richfaces-components-impl/pom.xml 2010-05-28 18:01:34 UTC (rev 17382)
+++ root/ui/dist/trunk/richfaces-components-impl/pom.xml 2010-05-28 18:10:52 UTC (rev 17383)
@@ -37,7 +37,7 @@
<properties>
<assembly.projects.group>org.richfaces.ui</assembly.projects.group>
- <faces-shade-transformers.version>1-SNAPSHOT</faces-shade-transformers.version>
+ <faces-shade-transformers.version>1</faces-shade-transformers.version>
</properties>
<dependencyManagement>
Modified: root/ui/dist/trunk/richfaces-components-ui/pom.xml
===================================================================
--- root/ui/dist/trunk/richfaces-components-ui/pom.xml 2010-05-28 18:01:34 UTC (rev 17382)
+++ root/ui/dist/trunk/richfaces-components-ui/pom.xml 2010-05-28 18:10:52 UTC (rev 17383)
@@ -36,7 +36,7 @@
<name>Richfaces UI Components UI</name>
<properties>
- <faces-shade-transformers.version>1-SNAPSHOT</faces-shade-transformers.version>
+ <faces-shade-transformers.version>1</faces-shade-transformers.version>
<assembly.projects.group>org.richfaces.ui</assembly.projects.group>
</properties>
Modified: root/ui/iteration/trunk/dist/richfaces-ui-iteration-api/pom.xml
===================================================================
--- root/ui/iteration/trunk/dist/richfaces-ui-iteration-api/pom.xml 2010-05-28 18:01:34 UTC (rev 17382)
+++ root/ui/iteration/trunk/dist/richfaces-ui-iteration-api/pom.xml 2010-05-28 18:10:52 UTC (rev 17383)
@@ -37,7 +37,7 @@
<properties>
<assembly.projects.group>org.richfaces.ui.iteration</assembly.projects.group>
- <faces-shade-transformers.version>1-SNAPSHOT</faces-shade-transformers.version>
+ <faces-shade-transformers.version>1</faces-shade-transformers.version>
</properties>
<dependencyManagement>
Modified: root/ui/iteration/trunk/dist/richfaces-ui-iteration-impl/pom.xml
===================================================================
--- root/ui/iteration/trunk/dist/richfaces-ui-iteration-impl/pom.xml 2010-05-28 18:01:34 UTC (rev 17382)
+++ root/ui/iteration/trunk/dist/richfaces-ui-iteration-impl/pom.xml 2010-05-28 18:10:52 UTC (rev 17383)
@@ -37,7 +37,7 @@
<properties>
<assembly.projects.group>org.richfaces.ui.iteration</assembly.projects.group>
- <faces-shade-transformers.version>1-SNAPSHOT</faces-shade-transformers.version>
+ <faces-shade-transformers.version>1</faces-shade-transformers.version>
</properties>
<dependencyManagement>
Modified: root/ui/iteration/trunk/dist/richfaces-ui-iteration-ui/pom.xml
===================================================================
--- root/ui/iteration/trunk/dist/richfaces-ui-iteration-ui/pom.xml 2010-05-28 18:01:34 UTC (rev 17382)
+++ root/ui/iteration/trunk/dist/richfaces-ui-iteration-ui/pom.xml 2010-05-28 18:10:52 UTC (rev 17383)
@@ -37,7 +37,7 @@
<properties>
<assembly.projects.group>org.richfaces.ui.iteration</assembly.projects.group>
- <faces-shade-transformers.version>1-SNAPSHOT</faces-shade-transformers.version>
+ <faces-shade-transformers.version>1</faces-shade-transformers.version>
</properties>
<dependencyManagement>
Modified: root/ui/misc/trunk/dist/richfaces-ui-misc-ui/pom.xml
===================================================================
--- root/ui/misc/trunk/dist/richfaces-ui-misc-ui/pom.xml 2010-05-28 18:01:34 UTC (rev 17382)
+++ root/ui/misc/trunk/dist/richfaces-ui-misc-ui/pom.xml 2010-05-28 18:10:52 UTC (rev 17383)
@@ -37,7 +37,7 @@
<properties>
<assembly.projects.group>org.richfaces.ui.misc</assembly.projects.group>
- <faces-shade-transformers.version>1-SNAPSHOT</faces-shade-transformers.version>
+ <faces-shade-transformers.version>1</faces-shade-transformers.version>
</properties>
<dependencyManagement>
14 years, 7 months
JBoss Rich Faces SVN: r17381 - root/build/resources/tags.
by richfaces-svn-commits@lists.jboss.org
Author: jbalunas(a)redhat.com
Date: 2010-05-28 14:01:25 -0400 (Fri, 28 May 2010)
New Revision: 17381
Added:
root/build/resources/tags/faces-shade-transformers-1/
Log:
[maven-scm] copy for tag faces-shade-transformers-1
Copied: root/build/resources/tags/faces-shade-transformers-1 (from rev 17380, root/build/resources/trunk/faces-shade-transformers)
14 years, 7 months
JBoss Rich Faces SVN: r17379 - root/ui/dist/trunk/richfaces-components-impl.
by richfaces-svn-commits@lists.jboss.org
Author: Alex.Kolonitsky
Date: 2010-05-28 14:00:46 -0400 (Fri, 28 May 2010)
New Revision: 17379
Modified:
root/ui/dist/trunk/richfaces-components-impl/pom.xml
Log:
fix impl
Modified: root/ui/dist/trunk/richfaces-components-impl/pom.xml
===================================================================
--- root/ui/dist/trunk/richfaces-components-impl/pom.xml 2010-05-28 17:59:19 UTC (rev 17378)
+++ root/ui/dist/trunk/richfaces-components-impl/pom.xml 2010-05-28 18:00:46 UTC (rev 17379)
@@ -36,6 +36,7 @@
<name>Richfaces UI Components Impl</name>
<properties>
+ <assembly.projects.group>org.richfaces.ui</assembly.projects.group>
<faces-shade-transformers.version>1-SNAPSHOT</faces-shade-transformers.version>
</properties>
@@ -53,7 +54,7 @@
<dependencies>
<dependency>
- <groupId>org.richfaces.ui</groupId>
+ <groupId>${assembly.projects.group}</groupId>
<artifactId>richfaces-ui-iteration-impl</artifactId>
</dependency>
14 years, 7 months
--- root/cdk/trunk/plugins/generator/src/main/java/org/richfaces/cdk/model/EventModel.java 2010-05-28 19:43:18 UTC (rev 17387)
+++ root/cdk/trunk/plugins/generator/src/main/java/org/richfaces/cdk/model/EventModel.java 2010-05-28 21:35:24 UTC (rev 17388)
@@ -44,7 +44,7 @@
public class EventModel implements ModelElement<EventModel> {
private String description;
private ClassName listenerInterface;
- private String listenerMethodName;
+ private String listenerMethod;
private boolean generateListener;
private ClassName sourceInterface;
private boolean generateSource;
@@ -108,19 +108,19 @@
/**
* <p class="changed_added_4_0"></p>
- * @return the listenerMethodName
+ * @return the listenerMethod
*/
@Merge
- public String getListenerMethodName() {
- return this.listenerMethodName;
+ public String getListenerMethod() {
+ return this.listenerMethod;
}
/**
* <p class="changed_added_4_0"></p>
* @param listenerMethodName the listenerMethodName to set
*/
- public void setListenerMethodName(String listenerMethodName) {
- this.listenerMethodName = listenerMethodName;
+ public void setListenerMethod(String listenerMethodName) {
+ this.listenerMethod = listenerMethodName;
}
/**
Modified: root/cdk/trunk/plugins/generator/src/main/java/org/richfaces/cdk/model/validator/ValidatorImpl.java
@@ -108,19 +108,19 @@
/**
* <p class="changed_added_4_0"></p>
- * @param listenerMethodName the listenerMethodName to set
+ * @param listenerMethod the listenerMethod to set
*/
===================================================================